==> google-cloud-build-3.2.1.tar.gz: google-cloud-build-3.2.1/google/cloud/devtools/cloudbuild/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.devtools.cloudbuild_v1.services.cloud_build.client import (
    CloudBuildClient,
)
from google.cloud.devtools.cloudbuild_v1.services.cloud_build.async_client import (
    CloudBuildAsyncClient,
)

from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ArtifactResult
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Artifacts
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Build
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildOperationMetadata
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildOptions
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildStep
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildTrigger
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuiltImage
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import CancelBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import CreateBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    CreateBuildTriggerRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import CreateWorkerPoolRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    DeleteBuildTriggerRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import DeleteWorkerPoolRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import FileHashes
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import GetBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import GetBuildTriggerRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import GetWorkerPoolRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import GitHubEventsConfig
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Hash
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import InlineSecret
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ListBuildsRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ListBuildsResponse
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    ListBuildTriggersRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    ListBuildTriggersResponse,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ListWorkerPoolsRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ListWorkerPoolsResponse
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Network
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import PubsubConfig
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import PullRequestFilter
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import PushFilter
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    ReceiveTriggerWebhookRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    ReceiveTriggerWebhookResponse,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import RepoSource
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Results
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import RetryBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import RunBuildTriggerRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Secret
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import SecretManagerSecret
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Secrets
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Source
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import SourceProvenance
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import StorageSource
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import StorageSourceManifest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import TimeSpan
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    UpdateBuildTriggerRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import UpdateWorkerPoolRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Volume
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import WorkerConfig
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import WorkerPool

__all__ = (
    "CloudBuildClient",
    "CloudBuildAsyncClient",
    "ArtifactResult",
    "Artifacts",
    "Build",
    "BuildOperationMetadata",
    "BuildOptions",
    "BuildStep",
    "BuildTrigger",
    "BuiltImage",
    "CancelBuildRequest",
    "CreateBuildRequest",
    "CreateBuildTriggerRequest",
    "CreateWorkerPoolRequest",
    "DeleteBuildTriggerRequest",
    "DeleteWorkerPoolRequest",
    "FileHashes",
    "GetBuildRequest",
    "GetBuildTriggerRequest",
    "GetWorkerPoolRequest",
    "GitHubEventsConfig",
    "Hash",
    "InlineSecret",
    "ListBuildsRequest",
    "ListBuildsResponse",
    "ListBuildTriggersRequest",
    "ListBuildTriggersResponse",
    "ListWorkerPoolsRequest",
    "ListWorkerPoolsResponse",
    "Network",
    "PubsubConfig",
    "PullRequestFilter",
    "PushFilter",
    "ReceiveTriggerWebhookRequest",
    "ReceiveTriggerWebhookResponse",
    "RepoSource",
    "Results",
    "RetryBuildRequest",
    "RunBuildTriggerRequest",
    "Secret",
    "SecretManagerSecret",
    "Secrets",
    "Source",
    "SourceProvenance",
    "StorageSource",
    "StorageSourceManifest",
    "TimeSpan",
    "UpdateBuildTriggerRequest",
    "UpdateWorkerPoolRequest",
    "Volume",
    "WorkerConfig",
    "WorkerPool",
)

==> google-cloud-build-3.5.1.tar.gz: google-cloud-build-3.5.1/google/cloud/devtools/cloudbuild/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.devtools.cloudbuild_v1.services.cloud_build.client import (
    CloudBuildClient,
)
from google.cloud.devtools.cloudbuild_v1.services.cloud_build.async_client import (
    CloudBuildAsyncClient,
)

from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ApprovalConfig
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ApprovalResult
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ApproveBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ArtifactResult
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Artifacts
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Build
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildApproval
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildOperationMetadata
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildOptions
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildStep
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuildTrigger
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import BuiltImage
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import CancelBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import CreateBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    CreateBuildTriggerRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    CreateWorkerPoolOperationMetadata,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import CreateWorkerPoolRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    DeleteBuildTriggerRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    DeleteWorkerPoolOperationMetadata,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import DeleteWorkerPoolRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import FileHashes
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import GetBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import GetBuildTriggerRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import GetWorkerPoolRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import GitHubEventsConfig
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Hash
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import InlineSecret
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ListBuildsRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ListBuildsResponse
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    ListBuildTriggersRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    ListBuildTriggersResponse,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ListWorkerPoolsRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import ListWorkerPoolsResponse
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import PrivatePoolV1Config
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import PubsubConfig
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import PullRequestFilter
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import PushFilter
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    ReceiveTriggerWebhookRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    ReceiveTriggerWebhookResponse,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import RepoSource
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Results
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import RetryBuildRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import RunBuildTriggerRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Secret
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import SecretManagerSecret
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Secrets
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Source
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import SourceProvenance
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import StorageSource
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import StorageSourceManifest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import TimeSpan
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    UpdateBuildTriggerRequest,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import (
    UpdateWorkerPoolOperationMetadata,
)
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import UpdateWorkerPoolRequest
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import Volume
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import WebhookConfig
from google.cloud.devtools.cloudbuild_v1.types.cloudbuild import WorkerPool

__all__ = (
    "CloudBuildClient",
    "CloudBuildAsyncClient",
    "ApprovalConfig",
    "ApprovalResult",
    "ApproveBuildRequest",
    "ArtifactResult",
    "Artifacts",
    "Build",
    "BuildApproval",
    "BuildOperationMetadata",
    "BuildOptions",
    "BuildStep",
    "BuildTrigger",
    "BuiltImage",
    "CancelBuildRequest",
    "CreateBuildRequest",
    "CreateBuildTriggerRequest",
    "CreateWorkerPoolOperationMetadata",
    "CreateWorkerPoolRequest",
    "DeleteBuildTriggerRequest",
    "DeleteWorkerPoolOperationMetadata",
    "DeleteWorkerPoolRequest",
    "FileHashes",
    "GetBuildRequest",
    "GetBuildTriggerRequest",
    "GetWorkerPoolRequest",
    "GitHubEventsConfig",
    "Hash",
    "InlineSecret",
    "ListBuildsRequest",
    "ListBuildsResponse",
    "ListBuildTriggersRequest",
    "ListBuildTriggersResponse",
    "ListWorkerPoolsRequest",
    "ListWorkerPoolsResponse",
    "PrivatePoolV1Config",
    "PubsubConfig",
    "PullRequestFilter",
    "PushFilter",
    "ReceiveTriggerWebhookRequest",
    "ReceiveTriggerWebhookResponse",
    "RepoSource",
    "Results",
    "RetryBuildRequest",
    "RunBuildTriggerRequest",
    "Secret",
    "SecretManagerSecret",
    "Secrets",
    "Source",
    "SourceProvenance",
    "StorageSource",
    "StorageSourceManifest",
    "TimeSpan",
    "UpdateBuildTriggerRequest",
    "UpdateWorkerPoolOperationMetadata",
    "UpdateWorkerPoolRequest",
    "Volume",
    "WebhookConfig",
    "WorkerPool",
)
